@@ -24,11 +24,12 @@ QUEUE = Queue()
 
 class Client(object):
 
-    def __init__(self):
+    def __init__(self, name='default'):
         self.msisdn = None
+        smpp_config = 'SMPP_{}'.format(name)
         self.smpp_client = smpplib.client.Client(
-            CONFIG['SMPP_SERVER']['host'],
-            int(CONFIG['SMPP_SERVER']['port'])
+            CONFIG[smpp_config]['host'],
+            int(CONFIG[smpp_config]['port'])
             )
         self.smpp_client.set_message_sent_handler(self.callback)
         self.smpp_client.set_message_received_handler(self.callback)
@@ -39,8 +40,8 @@ class Client(object):
             raise SystemError("Impossible de se connecter au SMSC")
         else:
             self.smpp_client.bind_transceiver(
-                system_id=CONFIG['SMPP_SERVER']['username'],
-                password=CONFIG['SMPP_SERVER']['password']
+                system_id=CONFIG[smpp_config]['username'],
+                password=CONFIG[smpp_config]['password']
                 )
             from threading import Thread
             t = Thread(target=self.listen)
@@ -72,13 +73,20 @@ class Client(object):
         """Envoi du SMS au SMSC"""
         self.msisdn = msisdn
         self.sender_id = kwargs.get('sender_id', 'bip')
+        try:
+            source = CONFIG[self.sender_id]['source']
+        except KeyError:
+            source = CONFIG['bip']['source']
         self.request_id = kwargs['request_id']
         self.infos = {
             'msisdn': msisdn,
             'submit': False
             }
         if not simulate:
-            destination = '261{}'.format(msisdn[-9:])
+            if not kwargs.get('intl'):
+                destination = '261{}'.format(msisdn[-9:])
+            else:
+                destination = msisdn
             parts, encoding_flag, msg_type_flag = smpplib.gsm.make_parts(
                 message
                 )
@@ -88,7 +96,7 @@ class Client(object):
                 pdu = self.smpp_client.send_message(  # NOQA
                     source_addr_ton=0,
                     source_addr_npi=0,
-                    source_addr=CONFIG[self.sender_id]['source'],
+                    source_addr=source,
                     dest_addr_ton=0,
                     dest_addr_npi=0,
                     destination_addr=destination,
